Module Descriptions
===================

All packages should be imported starting with "seapy"


**seapy**  (``seapy``)

     * General utilities for working with oceanographic data


**model** (``seapy.model``)

     * Utilities for working with models

**roms** (``seapy.roms``)

      * Module for working with ROMS directly
          + Nest grids
          + Generate Initial and Boundary Conditions
          + Create ROMS NetCDF files

**seawater** (``seapy.seawater``)

     * Utilities for computing oceanic properties

